@@ -17,20 +17,26 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 
-
+#include <glibmm/i18n.h>
 #include <gtkmm/main.h>
 
 #include "gnote.hpp"
 
 int main(int argc, char **argv)
 {
-//	if(!Glib::thread_supported()) {
-//		Glib::thread_init();
-//	}
-	Gtk::Main kit(argc, argv);
-	gnote::Gnote *app = &gnote::Gnote::obj();
-	int retval = app->main(argc, argv);
+//  if(!Glib::thread_supported()) {
+//    Glib::thread_init();
+//  }
+
+  bindtextdomain(GETTEXT_PACKAGE, GNOTE_LOCALEDIR);
+  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  textdomain(GETTEXT_PACKAGE);
+
+  Gtk::Main kit(argc, argv);
+  gnote::Gnote *app = &gnote::Gnote::obj();
+  int retval = app->main(argc, argv);
   delete app;
   return retval;
 }
