@@ -39,8 +39,9 @@
 #include "gnote.hpp"
 #include "tagmanager.hpp"
 #include "trie.hpp"
-#include "sharp/exception.hpp"
 #include "sharp/directory.hpp"
+#include "sharp/exception.hpp"
+#include "sharp/files.hpp"
 #include "sharp/uuid.hpp"
 #include "sharp/string.hpp"
 #include "sharp/datetime.hpp"
@@ -72,7 +73,9 @@ namespace gnote {
     return (a->change_date() > b->change_date());
   }
 
-  NoteManager::NoteManager(const std::string & directory)
+  NoteManager::NoteManager(const std::string & directory,
+                           const NoteChangedSlot & start_created)
+    : m_signal_start_note_created(start_created)
   {
     std::string backup = directory + "/Backup";
     
@@ -80,7 +83,10 @@ namespace gnote {
   }
 
 
-  NoteManager::NoteManager(const std::string & directory, const std::string & backup)
+  NoteManager::NoteManager(const std::string & directory, 
+                           const std::string & backup,
+                           const NoteChangedSlot & start_created)
+    : m_signal_start_note_created(start_created)
   {
     _common_init(directory, backup);
   }
@@ -113,6 +119,26 @@ namespace gnote {
     m_addin_mgr = create_addin_manager ();
 
     if (is_first_run) {
+      std::list<ImportAddin*> l;
+      m_addin_mgr->get_import_addins(l);
+      bool has_imported = false;
+
+      if(l.empty()) {
+        DBG_OUT("no import plugins");
+      }
+
+      for(std::list<ImportAddin*>::iterator iter = l.begin();
+          iter != l.end(); ++iter) {
+
+        DBG_OUT("importing");
+        (*iter)->initialize();
+        if((*iter)->want_to_run(*this)) {
+          has_imported |= (*iter)->first_run(*this);
+        }
+      }
+      // we MUST call this after import
+      post_load();
+
       // First run. Create "Start Here" notes.
       create_start_notes ();
     } 
@@ -150,9 +176,7 @@ namespace gnote {
 
   AddinManager *NoteManager::create_addin_manager() const
   {
-    std::string gnote_conf_dir = Gnote::conf_dir();
-    
-    return new AddinManager(gnote_conf_dir);
+    return new AddinManager(m_notes_dir);
   }
 
   // For overriding in test methods.
@@ -217,7 +241,7 @@ namespace gnote {
         "your ideas and thoughts.\n\n"
         "You can create new notes to hold your ideas by "
         "selecting the \"Create New Note\" item from the "
-        "Gnote Notes menu in your GNOME Panel. "
+        "Gnote menu in your GNOME Panel. "
         "Your note will be saved automatically.\n\n"
         "Then organize the notes you create by linking "
         "related notes and ideas together!\n\n"
@@ -253,13 +277,23 @@ namespace gnote {
                                 links_note_content);
       links_note->queue_save (Note::CONTENT_CHANGED);
 
-      start_note->get_window()->show();
+      m_signal_start_note_created(start_note);
     } 
     catch (const std::exception & e) {
       ERR_OUT("Error creating start notes: %s",
               e.what());
     }
   }
+
+
+  void NoteManager::add_note(const Note::Ptr & note)
+  {
+    if (note) {
+      note->signal_renamed().connect(sigc::mem_fun(*this, &NoteManager::on_note_rename));
+      note->signal_saved().connect(sigc::mem_fun(*this, &NoteManager::on_note_save));
+      m_notes.push_back(note);
+    }
+  }
   
   void NoteManager::load_notes()
   {
@@ -271,18 +305,31 @@ namespace gnote {
       const std::string & file_path(*iter);
       try {
         Note::Ptr note = Note::load(file_path, *this);
-        if (note) {
-          note->signal_renamed().connect(sigc::mem_fun(*this, &NoteManager::on_note_rename));
-          note->signal_saved().connect(sigc::mem_fun(*this, &NoteManager::on_note_save));
-          m_notes.push_back(note);
-        }
+        add_note(note);
       } 
       catch (const std::exception & e) {
         ERR_OUT("Error parsing note XML, skipping \"%s\": %s",
                 file_path.c_str(), e.what());
       }
     }
-      
+    post_load();
+    // Make sure that a Start Note Uri is set in the preferences, and
+    // make sure that the Uri is valid to prevent bug #508982. This
+    // has to be done here for long-time Tomboy users who won't go
+    // through the create_start_notes () process.
+    if (start_note_uri().empty() ||
+        !find_by_uri(start_note_uri())) {
+      // Attempt to find an existing Start Here note
+      Note::Ptr start_note = find (_("Start Here"));
+      if (start_note) {
+        Preferences::obj().set<std::string>(Preferences::START_NOTE_URI, start_note->uri());
+      }
+    }
+  }
+
+
+  void NoteManager::post_load()
+  {
     m_notes.sort (boost::bind(&compare_dates, _1, _2));
 
     // Update the trie so addins can access it, if they want.
@@ -310,20 +357,6 @@ namespace gnote {
         note->queue_save (Note::NO_CHANGE);
       }
     }
-
-    // Make sure that a Start Note Uri is set in the preferences, and
-    // make sure that the Uri is valid to prevent bug #508982. This
-    // has to be done here for long-time Tomboy users who won't go
-    // through the create_start_notes () process.
-    if (start_note_uri().empty() ||
-        !find_by_uri(start_note_uri())) {
-      // Attempt to find an existing Start Here note
-      Note::Ptr start_note = find (_("Start Here"));
-      if (start_note) {
-        Preferences::obj().set<std::string>(Preferences::START_NOTE_URI, start_note->uri());
-      }
-    }
-    
   }
 
   bool NoteManager::on_exiting_event()
@@ -370,7 +403,7 @@ namespace gnote {
           boost::filesystem::create_directory(m_backup_dir);
         }
         std::string backup_path 
-          = m_backup_dir + "/" + boost::filesystem::path(note->file_path()).leaf();
+          = Glib::build_filename(m_backup_dir, sharp::file_filename(note->file_path()));
           
         if (boost::filesystem::exists(backup_path))
           boost::filesystem::remove(backup_path);
@@ -398,7 +431,7 @@ namespace gnote {
 
   std::string NoteManager::make_new_file_name(const std::string & guid) const
   {
-    return m_notes_dir + "/" + guid + ".note";
+    return Glib::build_filename(m_notes_dir, guid + ".note");
   }
 
   Note::Ptr NoteManager::create()
@@ -456,6 +489,29 @@ namespace gnote {
     return create_new_note(title, xml_content, "");
   }
 
+  Note::Ptr NoteManager::import_note(const std::string & file_path)
+  {
+    std::string dest_file = Glib::build_filename(m_notes_dir, 
+                                                 sharp::file_filename(file_path));
+    
+    if(sharp::file_exists(dest_file)) {
+      dest_file = make_new_file_name();
+    }
+    Note::Ptr note;
+    try {
+      sharp::file_copy(file_path, dest_file);
+
+      // TODO: make sure the title IS unique.
+      note = Note::load(dest_file, *this);
+      add_note(note);
+    }
+    catch(...)
+    {
+    }
+    return note;
+  }
+
+
   Note::Ptr NoteManager::create_with_guid (const std::string & title, std::string & guid)
   {
     return create_new_note(title, guid);
