@@ -248,8 +248,7 @@ namespace gnote {
       align->show();
       options_list->pack_start (*align, false, false, 0);
       
-      Gtk::LinkButton *open_template_button = manage(new Gtk::LinkButton (
-                                                      "",  _("Open New Note Template")));
+      Gtk::Button *open_template_button = manage(new Gtk::Button (_("Open New Note Template")));
 
       open_template_button->signal_clicked().connect(
         sigc::mem_fun(*this, &PreferencesDialog::open_template_button_clicked));
@@ -907,7 +906,7 @@ namespace gnote {
     add_button(Gtk::Stock::CLOSE, Gtk::RESPONSE_CLOSE);
     
     // TODO: Change this icon to be an addin/package icon
-    Gtk::Image *icon = manage(new Gtk::Image(Gtk::Stock::INFO, 
+    Gtk::Image *icon = manage(new Gtk::Image(Gtk::Stock::DIALOG_INFO, 
                                              Gtk::ICON_SIZE_DIALOG));
     icon->property_yalign() = 0;
 
