@@ -24,7 +24,6 @@
 #include <glibmm/i18n.h>
 #include <gtkmm/image.h>
 #include <gtkmm/main.h>
-#include <gtkmm/paned.h>
 #include <gtkmm/stock.h>
 #include <gtkmm/table.h>
 #include <gtkmm/treestore.h>
@@ -153,8 +152,8 @@ namespace gnote {
     m_tree = manage(m_tree);
     m_tree->show ();
 
-    m_note_count.property_xalign() = 0;
-    m_note_count.show ();
+    m_status_bar.set_has_resize_grip(true);
+    m_status_bar.show();
 
     // Update on changes to notes
     m.signal_note_deleted.connect(sigc::mem_fun(*this, &NoteRecentChanges::on_notes_changed));
@@ -174,28 +173,23 @@ namespace gnote {
     m_tree->get_size_request (h,w);
     m_matches_window.set_size_request(std::min(h, 420), std::min(w, 480));
                         
-    restore_position ();
-
     m_matches_window.property_hscrollbar_policy() = Gtk::POLICY_AUTOMATIC;
     m_matches_window.property_vscrollbar_policy() = Gtk::POLICY_AUTOMATIC;
     m_matches_window.add (*m_tree);
     m_matches_window.show ();
 
-    Gtk::HPaned *hpaned = manage(new Gtk::HPaned ());
-    hpaned->set_position(150);
-    hpaned->add1 (*notebooksPane);
-    hpaned->add2 (m_matches_window);
-    hpaned->show ();
+    m_hpaned.set_position(150);
+    m_hpaned.add1 (*notebooksPane);
+    m_hpaned.add2 (m_matches_window);
+    m_hpaned.show ();
 
-    Gtk::HBox *status_box = manage(new Gtk::HBox (false, 8));
-    status_box->pack_start (m_note_count, true, true, 0);
-    status_box->show ();
+    restore_position ();
 
     Gtk::VBox *vbox = manage(new Gtk::VBox (false, 8));
     vbox->set_border_width(6);
     vbox->pack_start (*hbox, false, false, 0);
-    vbox->pack_start (*hpaned, true, true, 0);
-    vbox->pack_start (*status_box, false, false, 0);
+    vbox->pack_start (m_hpaned, true, true, 0);
+    vbox->pack_start (m_status_bar, false, false, 0);
     vbox->show ();
 
     // Use another VBox to place the MenuBar
@@ -578,7 +572,9 @@ namespace gnote {
     try {
       const char * fmt;
       fmt = ngettext("Total: %1% note", "Total: %1% notes", total);
-      m_note_count.set_text(str(boost::format (fmt) % total));
+      std::string status = str(boost::format (fmt) % total);
+      m_status_bar.pop(0);
+      m_status_bar.push(status, 0);
     } 
     catch(const std::exception & e)
     {
@@ -592,7 +588,9 @@ namespace gnote {
     try {
       const char * fmt;
       fmt = ngettext("Matches: %1% note", "Matches: %1% notes", matches);
-      m_note_count.set_text(str(boost::format (fmt) % matches));
+      std::string status = str(boost::format (fmt) % matches);
+      m_status_bar.pop(0);
+      m_status_bar.push(status, 0);
     }
     catch(const std::exception & e)
     {
@@ -1005,8 +1003,9 @@ namespace gnote {
   void NoteRecentChanges::on_delete_note()
   {
     Note::List selected_notes = get_selected_notes ();
-    if (selected_notes.size() != 1)
+    if (selected_notes.empty()) {
       return;
+    }
                   
     noteutils::show_deletion_dialog(selected_notes, this);
   }
@@ -1542,6 +1541,8 @@ namespace gnote {
     prefs.set<int> (Preferences::SEARCH_WINDOW_Y_POS, y);
     prefs.set<int> (Preferences::SEARCH_WINDOW_WIDTH, width);
     prefs.set<int> (Preferences::SEARCH_WINDOW_HEIGHT, height);
+    prefs.set<int> (Preferences::SEARCH_WINDOW_SPLITTER_POS, 
+                    m_hpaned.get_position());
   }
         
    
@@ -1552,7 +1553,7 @@ namespace gnote {
     int y = prefs.get<int> (Preferences::SEARCH_WINDOW_Y_POS);
     int width = prefs.get<int> (Preferences::SEARCH_WINDOW_WIDTH);
     int height = prefs.get<int> (Preferences::SEARCH_WINDOW_HEIGHT);
-          
+    int pos = prefs.get<int> (Preferences::SEARCH_WINDOW_SPLITTER_POS);
 
     if((width == 0) || (height == 0)) {
       return;
@@ -1560,6 +1561,9 @@ namespace gnote {
           
     set_default_size(width, height);
     move (x, y);
+    if(pos) {
+      m_hpaned.set_position(pos);
+    }
   }
 
 
