@@ -401,7 +401,7 @@ namespace gnote {
 
   void NoteUrlWatcher::initialize ()
   {
-    m_url_tag = NoteTag::Ptr::cast_dynamic(get_note()->get_tag_table()->lookup("link:url"));
+    m_url_tag = get_note()->get_tag_table()->get_url_tag();
   }
 
 
@@ -413,9 +413,8 @@ namespace gnote {
 
   void NoteUrlWatcher::on_note_opened ()
   {
-#if FIXED_GTKSPELL
-    // NOTE: This hack helps avoid multiple URL opens for
-    // cases where the GtkSpell version is fixed to allow
+    // NOTE: This hack helps avoid multiple URL opens
+    // now that Notes always perform
     // TagTable sharing.  This is because if the TagTable is
     // shared, we will connect to the same Tag's event
     // source each time a note is opened, and get called
@@ -426,10 +425,6 @@ namespace gnote {
         sigc::mem_fun(*this, &NoteUrlWatcher::on_url_tag_activated));
       s_text_event_connected = true;
     }
-#else
-    m_url_tag->signal_activate().connect(
-      sigc::mem_fun(*this, &NoteUrlWatcher::on_url_tag_activated));
-#endif
 
     m_click_mark = get_buffer()->create_mark(get_buffer()->begin(), true);
 
@@ -643,12 +638,9 @@ namespace gnote {
     m_on_note_renamed_cid = manager().signal_note_renamed.connect(
       sigc::mem_fun(*this, &NoteLinkWatcher::on_note_renamed));
 
-    m_url_tag = NoteTag::Ptr::cast_dynamic(get_note()
-                                           ->get_tag_table()->lookup ("link:url"));
-    m_link_tag = NoteTag::Ptr::cast_dynamic(get_note()
-                                            ->get_tag_table()->lookup ("link:internal"));
-    m_broken_link_tag = NoteTag::Ptr::cast_dynamic(get_note()
-                                                   ->get_tag_table()->lookup ("link:broken"));
+    m_url_tag = get_note()->get_tag_table()->get_url_tag();
+    m_link_tag = get_note()->get_tag_table()->get_link_tag();
+    m_broken_link_tag = get_note()->get_tag_table()->get_broken_link_tag();
   }
 
 
@@ -662,9 +654,8 @@ namespace gnote {
 
   void NoteLinkWatcher::on_note_opened ()
   {
-#if FIXED_GTKSPELL
-    // NOTE: This avoid multiple link opens for cases where
-    // the GtkSpell version is fixed to allow TagTable
+    // NOTE: This avoid multiple link opens
+    // now that notes always perform TagTable
     // sharing.  This is because if the TagTable is shared,
     // we will connect to the same Tag's event source each
     // time a note is opened, and get called multiple times
@@ -676,12 +667,6 @@ namespace gnote {
         sigc::mem_fun(*this, &NoteLinkWatcher::on_link_tag_activated));
       s_text_event_connected = true;
     }
-#else
-    m_link_tag->signal_activate().connect(
-      sigc::mem_fun(*this, &NoteLinkWatcher::on_link_tag_activated));
-    m_broken_link_tag->signal_activate().connect(
-      sigc::mem_fun(*this, &NoteLinkWatcher::on_link_tag_activated));
-#endif
     get_buffer()->signal_insert().connect(
       sigc::mem_fun(*this, &NoteLinkWatcher::on_insert_text));
     get_buffer()->signal_erase().connect(
@@ -950,7 +935,7 @@ namespace gnote {
 
   void NoteWikiWatcher::initialize ()
   {
-    m_broken_link_tag = get_note()->get_tag_table()->lookup ("link:broken");
+    m_broken_link_tag = get_note()->get_tag_table()->get_broken_link_tag();
   }
 
 
@@ -993,30 +978,6 @@ namespace gnote {
     }
   }
 
-  static const char * PATRONYMIC_PREFIXES[] = { 
-    "Mc", 
-    "Mac", 
-    "Le", 
-    "La", 
-    "De", 
-    "Van",
-    NULL
-  };
-
-  bool NoteWikiWatcher::is_patronymic_name (const std::string & word)
-  {
-    const char **prefix = PATRONYMIC_PREFIXES;
-    while(*prefix) {
-      if (sharp::string_starts_with(word, *prefix) &&
-          isupper(word [strlen(*prefix)])) {
-        return true;
-      }
-      prefix++;
-    }
-
-    return false;
-  }
-
   void NoteWikiWatcher::apply_wikiword_to_block (Gtk::TextIter start, Gtk::TextIter end)
   {
     NoteBuffer::get_block_extents (start,
@@ -1034,23 +995,20 @@ namespace gnote {
 
     while(m_regex.FindAndConsume(&input, &match)) {
 
-      if (!is_patronymic_name (match)) {
-      
-        Gtk::TextIter start_cpy = start;
-        Glib::ustring::size_type len = input.data() - p - match.size();
-        Glib::ustring segment(p, p + len);
-        start_cpy.forward_chars (segment.length());
+      Gtk::TextIter start_cpy = start;
+      Glib::ustring::size_type len = input.data() - p - match.size();
+      Glib::ustring segment(p, p + len);
+      start_cpy.forward_chars (segment.length());
 
-        DBG_OUT("Highlighting wikiword: '%s' at offset %d",
-                match.c_str(), segment.length());
+      DBG_OUT("Highlighting wikiword: '%s' at offset %d",
+              match.c_str(), segment.length());
 
-        end = start_cpy;
-        segment = match;
-        end.forward_chars (segment.length());
+      end = start_cpy;
+      segment = match;
+      end.forward_chars (segment.length());
 
-        if (!manager().find(match)) {
-          get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
-        }
+      if (!manager().find(match)) {
+        get_buffer()->apply_tag (m_broken_link_tag, start_cpy, end);
       }
     }
   }
